@@ -3,16 +3,14 @@ from vista_api_client.api_resources.api_resource import ApiResource, HttpMethods
 
 
 class ResourceTypes(ApiResource):
-    def list(self, environment):
+    def list(self):
         return self.dispatch('/v1/resource_types', HttpMethods.GET, {
-            'environment': environment,
+            'branch': self.branch,
         })
 
-    def create(self, name, relationships, attributes, actions, environment):
+    def create(self, name, actions):
         return self.dispatch('/v1/resource_types', HttpMethods.POST, {
             'name': name,
-            'relationships': relationships,
-            'attributes': attributes,
             'actions': actions,
-            'environment': environment,
+            'branch': self.branch,
         })
